@@ -3,11 +3,12 @@ from __future__ import print_function, division, absolute_import
 import gzip
 import os
 import os.path
+import pickle
 import sys
 from contextlib import contextmanager
+from distutils.version import LooseVersion
 import posixpath
 import tempfile
-import getpass
 
 import pytest
 import fsspec
@@ -36,6 +37,7 @@ csv_files = {
     ".test.fakedata.1.csv": (b"a,b\n" b"1,2\n"),
     ".test.fakedata.2.csv": (b"a,b\n" b"3,4\n"),
 }
+odir = os.getcwd()
 
 
 @contextmanager
@@ -49,7 +51,6 @@ def filetexts(d, open=open, mode="t"):
     automatically switch to a temporary current directory, to avoid
     race conditions when running tests in parallel.
     """
-    odir = os.getcwd()
     dirname = tempfile.mkdtemp()
     try:
         os.chdir(dirname)
@@ -103,13 +104,7 @@ def test_urlpath_inference_errors():
     # Protocols differ
     with pytest.raises(ValueError) as err:
         get_fs_token_paths(["s3://test/path.csv", "/other/path.csv"])
-    assert "same protocol" in str(err.value)
-
-    # Unknown type
-    with pytest.raises(TypeError):
-        get_fs_token_paths(
-            {"sets/are.csv", "unordered/so/they.csv", "should/not/be.csvallowed.csv"}
-        )
+    assert "protocol" in str(err.value)
 
 
 def test_urlpath_expand_read():
@@ -207,7 +202,9 @@ def test_isfile():
     with filetexts(files, mode="b"):
         for f in files.keys():
             assert fs.isfile(f)
+            assert fs.isfile("file://" + f)
         assert not fs.isfile("not-a-file")
+        assert not fs.isfile("file://not-a-file")
 
 
 def test_isdir():
@@ -300,16 +297,40 @@ def test_globfind_dirs(tmpdir):
     fs.mkdir(tmpdir + "/dir")
     fs.touch(tmpdir + "/dir/afile")
     assert [tmpdir + "/dir"] == fs.glob(tmpdir + "/*")
+    assert fs.glob(tmpdir + "/*", detail=True)[tmpdir + "/dir"]["type"] == "directory"
+    assert (
+        fs.glob(tmpdir + "/dir/*", detail=True)[tmpdir + "/dir/afile"]["type"] == "file"
+    )
     assert [tmpdir + "/dir/afile"] == fs.find(tmpdir)
     assert [tmpdir + "/dir", tmpdir + "/dir/afile"] == fs.find(tmpdir, withdirs=True)
 
 
+def test_touch(tmpdir):
+    import time
+
+    fn = tmpdir + "/in/file"
+    fs = fsspec.filesystem("file", auto_mkdir=False)
+    with pytest.raises(OSError):
+        fs.touch(fn)
+    fs = fsspec.filesystem("file", auto_mkdir=True)
+    fs.touch(fn)
+    info = fs.info(fn)
+    time.sleep(0.2)
+    fs.touch(fn)
+    info2 = fs.info(fn)
+    if not WIN:
+        assert info2["mtime"] > info["mtime"]
+
+
 def test_get_pyarrow_filesystem():
     pa = pytest.importorskip("pyarrow")
 
     fs = LocalFileSystem()
-    assert isinstance(fs, pa.filesystem.FileSystem)
-    assert fs._get_pyarrow_filesystem() is fs
+    if LooseVersion(pa.__version__) < LooseVersion("2.0"):
+        assert isinstance(fs, pa.filesystem.FileSystem)
+        assert fs._get_pyarrow_filesystem() is fs
+    else:
+        assert not isinstance(fs, pa.filesystem.FileSystem)
 
     class UnknownFileSystem(object):
         pass
@@ -329,7 +350,7 @@ def test_directories(tmpdir):
 
 def test_file_ops(tmpdir):
     tmpdir = make_path_posix(str(tmpdir))
-    fs = LocalFileSystem()
+    fs = LocalFileSystem(auto_mkdir=True)
     with pytest.raises(FileNotFoundError):
         fs.info(tmpdir + "/nofile")
     fs.touch(tmpdir + "/afile")
@@ -348,6 +369,9 @@ def test_file_ops(tmpdir):
     fs.move(tmpdir + "/afile", tmpdir + "/afile3")
     assert not fs.exists(tmpdir + "/afile")
 
+    fs.cp(tmpdir + "/afile3", tmpdir + "/deeply/nested/file")
+    assert fs.exists(tmpdir + "/deeply/nested/file")
+
     fs.rm(tmpdir + "/afile3", recursive=True)
     assert not fs.exists(tmpdir + "/afile3")
 
@@ -464,9 +488,65 @@ def test_isfilestore():
     assert fs._isfilestore()
 
 
+def test_pickle(tmpdir):
+    fs = LocalFileSystem()
+    tmpdir = str(tmpdir)
+    fn0 = os.path.join(tmpdir, "target")
+
+    with open(fn0, "wb") as f:
+        f.write(b"data")
+
+    f = fs.open(fn0, "rb")
+    f.seek(1)
+    f2 = pickle.loads(pickle.dumps(f))
+    assert f2.read() == f.read()
+
+    f = fs.open(fn0, "wb")
+    with pytest.raises(ValueError):
+        pickle.dumps(f)
+
+
 def test_strip_protocol_expanduser():
     path = "file://~\\foo\\bar" if sys.platform == "win32" else "file://~/foo/bar"
     stripped = LocalFileSystem._strip_protocol(path)
     assert path != stripped
     assert "file://" not in stripped
-    assert getpass.getuser() in stripped
+    assert stripped.startswith(os.path.expanduser("~"))
+
+
+def test_iterable(tmpdir):
+    data = b"a\nhello\noi"
+    fn = os.path.join(tmpdir, "test")
+    with open(fn, "wb") as f:
+        f.write(data)
+    of = fsspec.open("file://%s" % fn, "rb")
+    with of as f:
+        out = list(f)
+    assert b"".join(out) == data
+
+
+def test_mv_empty(tmpdir):
+    localfs = fsspec.filesystem("file")
+    src = os.path.join(str(tmpdir), "src")
+    dest = os.path.join(str(tmpdir), "dest")
+    assert localfs.isdir(src) is False
+    localfs.mkdir(src)
+    assert localfs.isdir(src)
+    localfs.move(src, dest, recursive=True)
+    assert localfs.isdir(src) is False
+    assert localfs.isdir(dest)
+    assert localfs.info(dest)
+
+
+def test_mv_recursive(tmpdir):
+    localfs = fsspec.filesystem("file")
+    src = os.path.join(str(tmpdir), "src")
+    dest = os.path.join(str(tmpdir), "dest")
+    assert localfs.isdir(src) is False
+    localfs.mkdir(src)
+    assert localfs.isdir(src)
+    localfs.touch(os.path.join(src, "afile"))
+    localfs.move(src, dest, recursive=True)
+    assert localfs.isdir(src) is False
+    assert localfs.isdir(dest)
+    assert localfs.info(os.path.join(dest, "afile"))
