@@ -359,3 +359,21 @@ def other_paths(paths, path2, is_dir=None):
     else:
         assert len(paths) == len(path2)
     return path2
+
+
+def is_exception(obj):
+    return isinstance(obj, BaseException)
+
+
+def setup_logger(logname, level="DEBUG"):
+    import logging
+
+    logger = logging.getLogger(logname)
+    handle = logging.StreamHandler()
+    formatter = logging.Formatter(
+        "%(asctime)s - %(name)s - %(levelname)s " "- %(message)s"
+    )
+    handle.setFormatter(formatter)
+    logger.addHandler(handle)
+    logger.setLevel(level)
+    return logger
